@@ -4,7 +4,6 @@ use v5.20;
 
 use strict;
 use warnings;
-use feature "switch";
 
 use Mouse;
 use Mouse::Util::TypeConstraints;
@@ -31,7 +30,7 @@ with "Config::Model::Role::HelpAsText";
 with "Config::Model::Role::ComputeFunction";
 
 use feature qw/postderef signatures/;
-no warnings qw/experimental::postderef experimental::smartmatch experimental::signatures/;
+no warnings qw/experimental::postderef experimental::signatures/;
 
 my $logger        = get_logger("Tree::Element::Value");
 my $user_logger   = get_logger("User");
